DEV_BASE_URL = 'https://newapidev.bni.co.id:8066';
UAT_BASE_URL = 'https://newapidev.bni.co.id:8065';
SANDBOX_BASE_URL = 'https://sandbox.bni.co.id';
SANDBOX_DEV_BASE_URL = 'https://sb-dev.harismawan.com';
PRODUCTION_BASE_URL = 'https://api.bni.co.id';
# DEV_OGP_URL = 'https://sandbox.harismawan.com'
# DEV_SNAP_BI = 'https://dev.harismawan.com'
TOKEN_JWT = 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJjbGllbnRJZCI6IklEQk5JVkdWemRDQkJVRkE9IiwiYWNjb3VudE5vIjoiMDExNTQ3NjExNyJ9.ljWtFHL0dHhLPw97U8SVWsFV3fRIJItHlQ-HPqCRUwc'
APP_NAME = 'Test APP'
APP_NAME_TEST = 'Test Wawat'

CLIENT_ID_BASE64 = 'IDBNIVGVzdCBBUFA='
API_SECRET = 'test-secret'  
API_KEY = '12345'
CLIENT_ID = 'test12345'
CLIENT_SECRET = 'test54321'
ACCOUNT_NO = '0115476117'

CLIENT_ID_ENCRYPT = 'e7954df3-b67b-43e8-9d41-203600c04185'
CLIENT_SECRET_ENCRYPT = 'a6d4f4db-ef4d-4521-982b-fbf4305e6eee'
API_KEY_ENCRYPT = '2ea45db2-c177-4862-84a3-42c84cb489cd'
API_SECRET_ENCRYPT = '43bb74c5-a591-4a94-9280-f16c452b8458'

################################################################
CLIENT_ID_ENCRYPT_SNAP_BI = '0bed55cb-c25d-4f07-9c5f-78f7c8aac9da'
CLIENT_SECRET_ENCRYPT_SNAP_BI = '46987047-6d56-410d-b43c-abdd247abac2'
API_KEY_ENCRYPT_SNAP_BI = '91ea86f6-387a-49f9-bc55-670e4d2ef67b'
API_SECRET_ENCRYPT_SNAP_BI = 'cc914c89-6b65-475d-a450-58ee4199a1b2'
